aboutsummaryrefslogtreecommitdiff
path: root/engines/titanic/star_control/unmarked_auto_mover.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'engines/titanic/star_control/unmarked_auto_mover.cpp')
-rw-r--r--engines/titanic/star_control/unmarked_auto_mover.cpp11
1 files changed, 6 insertions, 5 deletions
diff --git a/engines/titanic/star_control/unmarked_auto_mover.cpp b/engines/titanic/star_control/unmarked_auto_mover.cpp
index 424e143b58..429e42d29c 100644
--- a/engines/titanic/star_control/unmarked_auto_mover.cpp
+++ b/engines/titanic/star_control/unmarked_auto_mover.cpp
@@ -99,11 +99,12 @@ int CUnmarkedAutoMover::proc5(CErrorCode &errorCode, FVector &pos, FMatrix &orie
v2 = orientation._row3;
v3 = _destPos - pos;
- float unused_scale=0.0;
- if (!v3.normalize(unused_scale)) { // Do the normalization, put the scale amount in unused_scale,
- // but if it is unsuccessful, crash
- assert(unused_scale);
- }
+ float unusedScale = 0.0;
+ if (!v3.normalize(unusedScale)) {
+ // Do the normalization, put the scale amount in unusedScale,
+ // but if it is unsuccessful, crash
+ assert(unusedScale);
+ }
double val = orientation._row3._x * v3._x + orientation._row3._y * v3._y + orientation._row3._z * v3._z;
bool flag = false;